/***********************************************************
  文件名：17_IRremote.ino
  描述：红外遥控灯。
  作者：陈志强
  日期：2022.11.3
***********************************************************/
#include <IRremote.h>

volatile int red;
volatile int yellow;
volatile int green;
const String IR_PROTOCOL_TYPE[] = {
  "UNKNOWN",
  "PULSE_DISTANCE",
  "PULSE_WIDTH",
  "DENON",
  "DISH",
  "JVC",
  "LG",
  "LG2",
  "NEC",
  "PANASONIC",
  "KASEIKYO",
  "KASEIKYO_JVC",
  "KASEIKYO_DENON",
  "KASEIKYO_SHARP",
  "KASEIKYO_MITSUBISHI",
  "RC5",
  "RC6",
  "SAMSUNG",
  "SHARP",
  "SONY",
  "ONKYO",
  "APPLE",
  "BOSEWAVE",
  "LEGO_PF",
  "MAGIQUEST",
  "WHYNTER"
};
IRrecv irrecv_4(4);

void setup(){
  red = 11;
  yellow = 10;
  green = 9;
  Serial.begin(9600);
  irrecv_4.enableIRIn();
}

void loop(){
  if (irrecv_4.decode()) {
    struct IRData *pIrData = &irrecv_4.decodedIRData;
    long ir_item = pIrData->decodedRawData;
    String irProtocol = IR_PROTOCOL_TYPE[pIrData->protocol];
    Serial.print("IR TYPE:" + irProtocol + "\tVALUE:");
    Serial.println(ir_item, HEX);
    irrecv_4.resume();
    Serial.println(ir_item,HEX);
    switch (ir_item) {
     case 0xF30CFF00:
      //按下遥控器“1”键编码值：F30CFF00。红灯亮。
      pinMode(red, OUTPUT);
      digitalWrite(red,HIGH);
      pinMode(yellow, OUTPUT);
      digitalWrite(yellow,LOW);
      pinMode(green, OUTPUT);
      digitalWrite(green,LOW);
      break;
     case 0xE718FF00:
      //按下遥控器“2”键编码值：E718FF00。黄灯亮。
      pinMode(yellow, OUTPUT);
      digitalWrite(yellow,HIGH);
      pinMode(red, OUTPUT);
      digitalWrite(red,LOW);
      pinMode(green, OUTPUT);
      digitalWrite(green,LOW);
      break;
     case 0xA15EFF00:
      //按下遥控器“3”键编码值：A15EFF00。绿灯亮。
      pinMode(green, OUTPUT);
      digitalWrite(green,HIGH);
      pinMode(red, OUTPUT);
      digitalWrite(red,LOW);
      pinMode(yellow, OUTPUT);
      digitalWrite(yellow,LOW);
      break;
     case 0xBA45FF00:
      //按下遥控器“A”键编码值：BA45FF00。所以灯熄灭。
      pinMode(red, OUTPUT);
      digitalWrite(red,LOW);
      pinMode(yellow, OUTPUT);
      digitalWrite(yellow,LOW);
      pinMode(green, OUTPUT);
      digitalWrite(green,LOW);
      break;
     default:
      break;
    }

  } else {

  }

}
